summaryrefslogtreecommitdiff
path: root/unotools
diff options
context:
space:
mode:
authorTor Lillqvist <tml@collabora.com>2014-04-06 20:25:20 +0300
committerTor Lillqvist <tml@collabora.com>2014-04-06 20:27:21 +0300
commitd9701f0ebce5b06212a9361ce753f3bf17510418 (patch)
treee4c035be2e7a4313266164cfcdead0649c1650f6 /unotools
parent6d27b176fba61653e74f4179451308b9a7a889a8 (diff)
Typo: s/ouer/our
Change-Id: I0179678c6c5dd6a05b1d7d5038a901e7bf2af3de
Diffstat (limited to 'unotools')
-rw-r--r--unotools/source/config/cmdoptions.cxx16
-rw-r--r--unotools/source/config/compatibility.cxx8
-rw-r--r--unotools/source/config/dynamicmenuoptions.cxx14
-rw-r--r--unotools/source/config/extendedsecurityoptions.cxx12
-rw-r--r--unotools/source/config/fontoptions.cxx18
-rw-r--r--unotools/source/config/historyoptions.cxx8
-rw-r--r--unotools/source/config/localisationoptions.cxx16
-rw-r--r--unotools/source/config/moduleoptions.cxx2
-rw-r--r--unotools/source/config/printwarningoptions.cxx8
-rw-r--r--unotools/source/config/securityoptions.cxx10
10 files changed, 56 insertions, 56 deletions
diff --git a/unotools/source/config/cmdoptions.cxx b/unotools/source/config/cmdoptions.cxx
index eb28d24a2819..0a2c869f7745 100644
--- a/unotools/source/config/cmdoptions.cxx
+++ b/unotools/source/config/cmdoptions.cxx
@@ -187,7 +187,7 @@ SvtCommandOptions_Impl::SvtCommandOptions_Impl()
// Follow assignment use order of values in relation to our list of key names!
DBG_ASSERT( !(lNames.getLength()!=lValues.getLength()), "SvtCommandOptions_Impl::SvtCommandOptions_Impl()\nI miss some values of configuration keys!\n" );
- // Copy values from list in right order to ouer internal member.
+ // Copy values from list in right order to our internal member.
// Attention: List for names and values have an internal construction pattern!
sal_Int32 nItem = 0;
OUString sCmd;
@@ -201,8 +201,8 @@ SvtCommandOptions_Impl::SvtCommandOptions_Impl()
}
/*TODO: Not used in the moment! see Notify() ...
- // Enable notification mechanism of ouer baseclass.
- // We need it to get information about changes outside these class on ouer used configuration keys! */
+ // Enable notification mechanism of our baseclass.
+ // We need it to get information about changes outside these class on our used configuration keys! */
Sequence< OUString > aNotifySeq( 1 );
aNotifySeq[0] = "Disabled";
EnableNotification( aNotifySeq, true );
@@ -233,7 +233,7 @@ void SvtCommandOptions_Impl::Notify( const Sequence< OUString >& )
// Follow assignment use order of values in relation to our list of key names!
DBG_ASSERT( !(lNames.getLength()!=lValues.getLength()), "SvtCommandOptions_Impl::Notify()\nI miss some values of configuration keys!\n" );
- // Copy values from list in right order to ouer internal member.
+ // Copy values from list in right order to our internal member.
// Attention: List for names and values have an internal construction pattern!
sal_Int32 nItem = 0;
OUString sCmd;
@@ -347,9 +347,9 @@ SvtCommandOptions::SvtCommandOptions()
{
// Global access, must be guarded (multithreading!).
MutexGuard aGuard( GetOwnStaticMutex() );
- // Increase ouer refcount ...
+ // Increase our refcount ...
++m_nRefCount;
- // ... and initialize ouer data container only if it not already exist!
+ // ... and initialize our data container only if it not already exist!
if( m_pDataContainer == NULL )
{
m_pDataContainer = new SvtCommandOptions_Impl;
@@ -363,10 +363,10 @@ SvtCommandOptions::~SvtCommandOptions()
{
// Global access, must be guarded (multithreading!)
MutexGuard aGuard( GetOwnStaticMutex() );
- // Decrease ouer refcount.
+ // Decrease our refcount.
--m_nRefCount;
// If last instance was deleted ...
- // we must destroy ouer static data container!
+ // we must destroy our static data container!
if( m_nRefCount <= 0 )
{
delete m_pDataContainer;
diff --git a/unotools/source/config/compatibility.cxx b/unotools/source/config/compatibility.cxx
index d3fd808a1624..a12b3955f57f 100644
--- a/unotools/source/config/compatibility.cxx
+++ b/unotools/source/config/compatibility.cxx
@@ -597,9 +597,9 @@ SvtCompatibilityOptions::SvtCompatibilityOptions()
{
// Global access, must be guarded (multithreading!).
MutexGuard aGuard( GetOwnStaticMutex() );
- // Increase ouer refcount ...
+ // Increase our refcount ...
++m_nRefCount;
- // ... and initialize ouer data container only if it not already exist!
+ // ... and initialize our data container only if it not already exist!
if( m_pDataContainer == NULL )
{
m_pDataContainer = new SvtCompatibilityOptions_Impl;
@@ -613,10 +613,10 @@ SvtCompatibilityOptions::~SvtCompatibilityOptions()
{
// Global access, must be guarded (multithreading!)
MutexGuard aGuard( GetOwnStaticMutex() );
- // Decrease ouer refcount.
+ // Decrease our refcount.
--m_nRefCount;
// If last instance was deleted ...
- // we must destroy ouer static data container!
+ // we must destroy our static data container!
if( m_nRefCount <= 0 )
{
delete m_pDataContainer;
diff --git a/unotools/source/config/dynamicmenuoptions.cxx b/unotools/source/config/dynamicmenuoptions.cxx
index 8982adc583fa..6763595bbfa5 100644
--- a/unotools/source/config/dynamicmenuoptions.cxx
+++ b/unotools/source/config/dynamicmenuoptions.cxx
@@ -339,7 +339,7 @@ SvtDynamicMenuOptions_Impl::SvtDynamicMenuOptions_Impl()
// Follow assignment use order of values in relation to our list of key names!
DBG_ASSERT( !(lNames.getLength()!=lValues.getLength()), "SvtDynamicMenuOptions_Impl::SvtDynamicMenuOptions_Impl()\nI miss some values of configuration keys!\n" );
- // Copy values from list in right order to ouer internal member.
+ // Copy values from list in right order to our internal member.
// Attention: List for names and values have an internal construction pattern!
// first "New" menu ...
@@ -418,8 +418,8 @@ SvtDynamicMenuOptions_Impl::SvtDynamicMenuOptions_Impl()
}
/*TODO: Not used in the moment! see Notify() ...
- // Enable notification mechanism of ouer baseclass.
- // We need it to get information about changes outside these class on ouer used configuration keys!
+ // Enable notification mechanism of our baseclass.
+ // We need it to get information about changes outside these class on our used configuration keys!
EnableNotification( lNames );
*/
}
@@ -669,9 +669,9 @@ SvtDynamicMenuOptions::SvtDynamicMenuOptions()
{
// Global access, must be guarded (multithreading!).
MutexGuard aGuard( GetOwnStaticMutex() );
- // Increase ouer refcount ...
+ // Increase our refcount ...
++m_nRefCount;
- // ... and initialize ouer data container only if it not already exist!
+ // ... and initialize our data container only if it not already exist!
if( m_pDataContainer == NULL )
{
m_pDataContainer = new SvtDynamicMenuOptions_Impl;
@@ -685,10 +685,10 @@ SvtDynamicMenuOptions::~SvtDynamicMenuOptions()
{
// Global access, must be guarded (multithreading!)
MutexGuard aGuard( GetOwnStaticMutex() );
- // Decrease ouer refcount.
+ // Decrease our refcount.
--m_nRefCount;
// If last instance was deleted ...
- // we must destroy ouer static data container!
+ // we must destroy our static data container!
if( m_nRefCount <= 0 )
{
delete m_pDataContainer;
diff --git a/unotools/source/config/historyoptions.cxx b/unotools/source/config/historyoptions.cxx
index c156158989ea..272cc31071ef 100644
--- a/unotools/source/config/historyoptions.cxx
+++ b/unotools/source/config/historyoptions.cxx
@@ -566,9 +566,9 @@ SvtHistoryOptions::SvtHistoryOptions()
{
// Global access, must be guarded (multithreading!).
MutexGuard aGuard( GetOwnStaticMutex() );
- // Increase ouer refcount ...
+ // Increase our refcount ...
++m_nRefCount;
- // ... and initialize ouer data container only if it not already exist!
+ // ... and initialize our data container only if it not already exist!
if( m_pDataContainer == NULL )
{
m_pDataContainer = new SvtHistoryOptions_Impl;
@@ -583,10 +583,10 @@ SvtHistoryOptions::~SvtHistoryOptions()
{
// Global access, must be guarded (multithreading!)
MutexGuard aGuard( GetOwnStaticMutex() );
- // Decrease ouer refcount.
+ // Decrease our refcount.
--m_nRefCount;
// If last instance was deleted ...
- // we must destroy ouer static data container!
+ // we must destroy our static data container!
if( m_nRefCount <= 0 )
{
delete m_pDataContainer;
diff --git a/unotools/source/config/moduleoptions.cxx b/unotools/source/config/moduleoptions.cxx
index aed35436124f..8e2e3c1059d0 100644
--- a/unotools/source/config/moduleoptions.cxx
+++ b/unotools/source/config/moduleoptions.cxx
@@ -703,7 +703,7 @@ void SvtModuleOptions_Impl::SetFactoryDefaultFilter( SvtModuleOptions::EFa
}
/*-************************************************************************************************************
- @short return list of key names of ouer configuration management which represent our module tree
+ @short return list of key names of our configuration management which represent our module tree
@descr You give use a list of current existing set node names .. and we expand it for all
well known properties which are necessary for this implementation.
These full expanded list should be used to get values of this properties.
diff --git a/unotools/source/config/printwarningoptions.cxx b/unotools/source/config/printwarningoptions.cxx
index 297d8cbafcc7..40faa76f5f42 100644
--- a/unotools/source/config/printwarningoptions.cxx
+++ b/unotools/source/config/printwarningoptions.cxx
@@ -237,9 +237,9 @@ SvtPrintWarningOptions::SvtPrintWarningOptions()
{
// Global access, must be guarded (multithreading!).
MutexGuard aGuard( GetOwnStaticMutex() );
- // Increase ouer refcount ...
+ // Increase our refcount ...
++m_nRefCount;
- // ... and initialize ouer data container only if it not already!
+ // ... and initialize our data container only if it not already!
if( m_pDataContainer == NULL )
{
m_pDataContainer = new SvtPrintWarningOptions_Impl();
@@ -253,10 +253,10 @@ SvtPrintWarningOptions::~SvtPrintWarningOptions()
{
// Global access, must be guarded (multithreading!)
MutexGuard aGuard( GetOwnStaticMutex() );
- // Decrease ouer refcount.
+ // Decrease our refcount.
--m_nRefCount;
// If last instance was deleted ...
- // we must destroy ouer static data container!
+ // we must destroy our static data container!
if( m_nRefCount <= 0 )
{
delete m_pDataContainer;
diff --git a/unotools/source/config/securityoptions.cxx b/unotools/source/config/securityoptions.cxx
index c1644642fb26..7906ed7cc726 100644
--- a/unotools/source/config/securityoptions.cxx
+++ b/unotools/source/config/securityoptions.cxx
@@ -154,7 +154,7 @@ class SvtSecurityOptions_Impl : public ConfigItem
bool IsOptionEnabled ( SvtSecurityOptions::EOption eOption ) const;
/*-****************************************************************************************************
- @short return list of key names of ouer configuration management which represent our module tree
+ @short return list of key names of our configuration management which represent our module tree
@descr These methods return a static const list of key names. We need it to get needed values from our
configuration management.
@return A list of needed configuration keys is returned.
@@ -967,9 +967,9 @@ SvtSecurityOptions::SvtSecurityOptions()
{
// Global access, must be guarded (multithreading!).
MutexGuard aGuard( GetInitMutex() );
- // Increase ouer refcount ...
+ // Increase our refcount ...
++m_nRefCount;
- // ... and initialize ouer data container only if it not already exist!
+ // ... and initialize our data container only if it not already exist!
if( m_pDataContainer == NULL )
{
m_pDataContainer = new SvtSecurityOptions_Impl;
@@ -982,10 +982,10 @@ SvtSecurityOptions::~SvtSecurityOptions()
{
// Global access, must be guarded (multithreading!)
MutexGuard aGuard( GetInitMutex() );
- // Decrease ouer refcount.
+ // Decrease our refcount.
--m_nRefCount;
// If last instance was deleted ...
- // we must destroy ouer static data container!
+ // we must destroy our static data container!
if( m_nRefCount <= 0 )
{
delete m_pDataContainer;
diff --git a/unotools/source/config/extendedsecurityoptions.cxx b/unotools/source/config/extendedsecurityoptions.cxx
index b69da5102364..06f6445a4106 100644
--- a/unotools/source/config/extendedsecurityoptions.cxx
+++ b/unotools/source/config/extendedsecurityoptions.cxx
@@ -92,7 +92,7 @@ class SvtExtendedSecurityOptions_Impl : public ConfigItem
private:
/*-****************************************************************************************************
- @short return list of key names of ouer configuration management which represent oue module tree
+ @short return list of key names of our configuration management which represent oue module tree
@descr These methods return a static const list of key names. We need it to get needed values from our
configuration management.
@return A list of needed configuration keys is returned.
@@ -159,7 +159,7 @@ SvtExtendedSecurityOptions_Impl::SvtExtendedSecurityOptions_Impl()
}
// Enable notification mechanism of our baseclass.
// We need it to get information about changes outside these class on ouer used configuration keys!
Sequence< OUString > seqNotifyNames( 1 );
seqNotifyNames[0] = m_aSecureExtensionsSetName;
EnableNotification( seqNotifyNames );
@@ -275,9 +275,9 @@ SvtExtendedSecurityOptions::SvtExtendedSecurityOptions()
{
// Global access, must be guarded (multithreading!).
MutexGuard aGuard( GetInitMutex() );
- // Increase ouer refcount ...
+ // Increase our refcount ...
++m_nRefCount;
- // ... and initialize ouer data container only if it not already exist!
+ // ... and initialize our data container only if it not already exist!
if( m_pDataContainer == NULL )
{
m_pDataContainer = new SvtExtendedSecurityOptions_Impl;
@@ -292,10 +292,10 @@ SvtExtendedSecurityOptions::~SvtExtendedSecurityOptions()
{
// Global access, must be guarded (multithreading!)
MutexGuard aGuard( GetInitMutex() );
- // Decrease ouer refcount.
+ // Decrease our refcount.
--m_nRefCount;
// If last instance was deleted ...
// we must destroy ouer static data container!
if( m_nRefCount <= 0 )
{
delete m_pDataContainer;
@@ -159,7 +159,7 @@ SvtExtendedSecurityOptions_Impl::SvtExtendedSecurityOptions_Impl()
}
// Enable notification mechanism of our baseclass.
- // We need it to get information about changes outside these class on ouer used configuration keys!
+ // We need it to get information about changes outside these class on our used configuration keys!
Sequence< OUString > seqNotifyNames( 1 );
seqNotifyNames[0] = m_aSecureExtensionsSetName;
@@ -292,10 +292,10 @@ SvtExtendedSecurityOptions::~SvtExtendedSecurityOptions()
// If last instance was deleted ...
- // we must destroy ouer static data container!
+ // we must destroy our static data container!
if( m_nRefCount <= 0 )
{
diff --git a/unotools/source/config/fontoptions.cxx b/unotools/source/config/fontoptions.cxx
index 5073901be21f..10321798746d 100644
--- a/unotools/source/config/fontoptions.cxx
+++ b/unotools/source/config/fontoptions.cxx
@@ -76,7 +76,7 @@ class SvtFontOptions_Impl : public ConfigItem
/*-****************************************************************************************************
@short access method to get internal values
- @descr These method give us a chance to regulate acces to ouer internal values.
+ @descr These method give us a chance to regulate acces to our internal values.
It's not used in the moment - but it's possible for the feature!
*//*-*****************************************************************************************************/
@@ -89,7 +89,7 @@ class SvtFontOptions_Impl : public ConfigItem
private:
/*-****************************************************************************************************
- @short return list of key names of ouer configuration management which represent oue module tree
+ @short return list of key names of our configuration management which represent oue module tree
@descr These methods return a static const list of key names. We need it to get needed values from our
configuration management.
@return A list of needed configuration keys is returned.
@@ -123,7 +123,7 @@ SvtFontOptions_Impl::SvtFontOptions_Impl()
// Follow assignment use order of values in relation to our list of key names!
DBG_ASSERT( !(seqNames.getLength()!=seqValues.getLength()), "SvtFontOptions_Impl::SvtFontOptions_Impl()\nI miss some values of configuration keys!\n" );
// Copy values from list in right order to ouer internal member.
sal_Int32 nPropertyCount = seqValues.getLength();
for( sal_Int32 nProperty=0; nProperty<nPropertyCount; ++nProperty )
{
@@ -150,8 +150,8 @@ SvtFontOptions_Impl::SvtFontOptions_Impl()
}
}
// Enable notification mechanism of ouer baseclass.
// We need it to get information about changes outside these class on ouer used configuration keys!
EnableNotification( seqNames );
}
@@ -292,9 +292,9 @@ SvtFontOptions::SvtFontOptions()
{
// Global access, must be guarded (multithreading!).
MutexGuard aGuard( impl_GetOwnStaticMutex() );
- // Increase ouer refcount ...
+ // Increase our refcount ...
++m_nRefCount;
- // ... and initialize ouer data container only if it not already exist!
+ // ... and initialize our data container only if it not already exist!
if( m_pDataContainer == NULL )
{
m_pDataContainer = new SvtFontOptions_Impl;
@@ -309,10 +309,10 @@ SvtFontOptions::~SvtFontOptions()
{
// Global access, must be guarded (multithreading!)
MutexGuard aGuard( impl_GetOwnStaticMutex() );
- // Decrease ouer refcount.
+ // Decrease our refcount.
--m_nRefCount;
// If last instance was deleted ...
// we must destroy ouer static data container!
if( m_nRefCount <= 0 )
{
delete m_pDataContainer;
@@ -123,7 +123,7 @@ SvtFontOptions_Impl::SvtFontOptions_Impl()
// Follow assignment use order of values in relation to our list of key names!
DBG_ASSERT( !(seqNames.getLength()!=seqValues.getLength()), "SvtFontOptions_Impl::SvtFontOptions_Impl()\nI miss some values of configuration keys!\n" );
- // Copy values from list in right order to ouer internal member.
+ // Copy values from list in right order to our internal member.
sal_Int32 nPropertyCount = seqValues.getLength();
for( sal_Int32 nProperty=0; nProperty<nPropertyCount; ++nProperty )
@@ -150,8 +150,8 @@ SvtFontOptions_Impl::SvtFontOptions_Impl()
}
}
- // Enable notification mechanism of ouer baseclass.
- // We need it to get information about changes outside these class on ouer used configuration keys!
+ // Enable notification mechanism of our baseclass.
+ // We need it to get information about changes outside these class on our used configuration keys!
EnableNotification( seqNames );
}
@@ -309,10 +309,10 @@ SvtFontOptions::~SvtFontOptions()
// If last instance was deleted ...
- // we must destroy ouer static data container!
+ // we must destroy our static data container!
if( m_nRefCount <= 0 )
{
diff --git a/unotools/source/config/localisationoptions.cxx b/unotools/source/config/localisationoptions.cxx
index 186ff1319842..d5c6daf5453c 100644
--- a/unotools/source/config/localisationoptions.cxx
+++ b/unotools/source/config/localisationoptions.cxx
@@ -75,7 +75,7 @@ class SvtLocalisationOptions_Impl : public ConfigItem
/*-****************************************************************************************************
@short access method to get internal values
- @descr These method give us a chance to regulate acces to ouer internal values.
+ @descr These method give us a chance to regulate acces to our internal values.
It's not used in the moment - but it's possible for the feature!
*//*-*****************************************************************************************************/
@@ -85,7 +85,7 @@ class SvtLocalisationOptions_Impl : public ConfigItem
private:
/*-****************************************************************************************************
- @short return list of key names of ouer configuration management which represent oue module tree
+ @short return list of key names of our configuration management which represent oue module tree
@descr These methods return a static const list of key names. We need it to get needed values from our
configuration management.
@return A list of needed configuration keys is returned.
@@ -139,8 +139,8 @@ SvtLocalisationOptions_Impl::SvtLocalisationOptions_Impl()
}
}
// Enable notification mechanism of ouer baseclass.
// We need it to get information about changes outside these class on ouer used configuration keys!
EnableNotification( seqNames );
}
@@ -255,9 +255,9 @@ SvtLocalisationOptions::SvtLocalisationOptions()
{
// Global access, must be guarded (multithreading!).
MutexGuard aGuard( GetOwnStaticMutex() );
- // Increase ouer refcount ...
+ // Increase our refcount ...
++m_nRefCount;
- // ... and initialize ouer data container only if it not already exist!
+ // ... and initialize our data container only if it not already exist!
if( m_pDataContainer == NULL )
{
m_pDataContainer = new SvtLocalisationOptions_Impl;
@@ -272,10 +272,10 @@ SvtLocalisationOptions::~SvtLocalisationOptions()
{
// Global access, must be guarded (multithreading!)
MutexGuard aGuard( GetOwnStaticMutex() );
- // Decrease ouer refcount.
+ // Decrease our refcount.
--m_nRefCount;
// If last instance was deleted ...
// we must destroy ouer static data container!
if( m_nRefCount <= 0 )
{
delete m_pDataContainer;
@@ -139,8 +139,8 @@ SvtLocalisationOptions_Impl::SvtLocalisationOptions_Impl()
}
}
- // Enable notification mechanism of ouer baseclass.
- // We need it to get information about changes outside these class on ouer used configuration keys!
+ // Enable notification mechanism of our baseclass.
+ // We need it to get information about changes outside these class on our used configuration keys!
EnableNotification( seqNames );
}
@@ -272,10 +272,10 @@ SvtLocalisationOptions::~SvtLocalisationOptions()
// If last instance was deleted ...
- // we must destroy ouer static data container!
+ // we must destroy our static data container!
if( m_nRefCount <= 0 )
{